Questrade
---------

App registration (get your key here, follow "Creating your first personal app")
    https://www.questrade.com/api/documentation/getting-started
    https://apphub.questrade.com/UI/UserApps.aspx

Development callback URL (HTTPS is required).
    https://example.com/accounts/questrade/login/callback/
